JournalConfig

Struct JournalConfig 

pub struct JournalConfig {
    pub max_object_size_bytes: u64,
    pub max_decompressed_bytes: usize,
    pub max_field_name_len: usize,
    pub max_fields_per_entry: usize,
    pub max_journal_files: usize,
    pub max_object_chain_steps: usize,
    pub max_query_terms: usize,
    pub allow_mmap_online: bool,
    pub include_journal_tilde: bool,
    pub max_follow_backoff: Duration,
    pub poll_interval: Duration,
}
Runtime configuration for Journal.

Fields

max_object_size_bytes: u64

Maximum object size accepted from the journal file.

max_decompressed_bytes: usize

Maximum bytes allowed after decompressing a DATA payload.

max_field_name_len: usize

Maximum length of a field name.

max_fields_per_entry: usize

Maximum number of fields accepted per entry.

max_journal_files: usize

Maximum number of journal files included from a single scan.

max_object_chain_steps: usize

Maximum number of steps when traversing any next_* chain.

max_query_terms: usize

Maximum number of query terms (matches) accepted per query.

allow_mmap_online: bool

Whether to allow mmap for STATE_ONLINE (potentially still being written) journal files.

include_journal_tilde: bool

Whether to include *.journal~ temporary/incomplete files during discovery.

max_follow_backoff: Duration

Maximum follow retry backoff.

poll_interval: Duration

Polling interval used as fallback when inotify is unavailable/unreliable.